@@ -1,3 +1,4 @@
+import asyncio
 import re
 
 import requests
@@ -20,7 +21,7 @@ class InstagramParser(Parser):
     __platform_id__ = "instagram"
     __platform__ = "Instagram"
     __supported_type__ = ["视频", "图文"]
-    __match__ = r"^(http(s)?://)(www\.|)instagram\.com/(share/|.*)(p|reel)/.*"
+    __match__ = r"^(http(s)?://)(www\.|)instagram\.com/(share/|.*)(share|p|reel)/.*"
 
     async def parse(
         self, url: str
@@ -52,14 +53,21 @@ class InstagramParser(Parser):
 
     async def _parse(self, url, shortcode, cookie=None):
         try:
-            post = Post.from_shortcode(
-                MyInstaloaderContext(self.cfg.proxy, cookie), shortcode
+            post = await asyncio.wait_for(
+                asyncio.to_thread(
+                    Post.from_shortcode,
+                    MyInstaloaderContext(self.cfg.proxy, cookie),
+                    shortcode,
+                ),
+                30,
             )
+        except asyncio.TimeoutError:
+            raise ParseError("解析超时")
         except BadResponseException as e:
             match str(e):
                 case "Fetching Post metadata failed.":
                     if self.cfg.cookie and cookie is None:
-                        await self._parse(url, shortcode, self.cfg.cookie)
+                        return await self._parse(url, shortcode, self.cfg.cookie)
                     else:
                         raise ParseError(
                             "受限视频无法解析: 你必须年满 18 周岁才能观看这个视频"
