@@ -61,7 +61,7 @@ def match_url(text: str) -> str:
     """从文本中提取url"""
     if not text:
         return ""
-    text = re.sub(r"(https?://)", r" \1", text)
+    text = re.sub(r"(https?://)", r" \1", text)  # 协议前面增加空格, 方便提取
     url = URLExtract().find_urls(text, only_unique=True)
     return url[0] if url else ""
 
