@@ -21,12 +21,15 @@ class WeiboAPI:
 
     async def parse(self, url: str) -> "WeiboContent":
         bid = self.get_id_by_url(url)
+        headers = {
+            "referer": "https://weibo.com",
+        }
         cookies = {
             "SUB": "_2AkMR47Mlf8NxqwFRmfocxG_lbox2wg7EieKnv0L-JRMxHRl-yT9yqhFdtRB6OmOdyoia9pKPkqoHRRmSBA_WNPaHuybH",
         }
         api = f"https://weibo.com/ajax/statuses/show?id={bid}"
         async with httpx.AsyncClient(proxy=self.proxy) as client:
-            response = await client.get(api, cookies=cookies)
+            response = await client.get(api, cookies=cookies, headers=headers)
             response.raise_for_status()
             result = response.json()
         return WeiboContent.parse(result)
